%define libname libadns

Name:          adns
Version:       1.6.1
Release:       1mamba
Summary:       Advanced, easy to use, asynchronous-capable DNS client library
Group:         Applications/Networking
Vendor:        openmamba
Distribution:  openmamba
Packager:      Aleph0 <aleph0@openmamba.org>
URL:           http://www.chiark.greenend.org.uk/~ian/adns/
Source:        http://www.chiark.greenend.org.uk/~ian/adns/ftp/adns-%{version}.tar.gz
License:       GPL
Requires:      %{libname} = %{version}-%{release}

%description
adns is a resolver library for C (and C++) programs, and a collection of useful DNS resolver utilities for use from the command line and in scripts:
 * adnslogres is a much faster version of Apache's logresolv program.
 * adnsresfilter is a filter which copies its input to its output,
   replacing IP addresses by the corresponding names, without unduly
   delaying the output. For example, you can usefully pipe the output
   of netstat -n, tcpdump -ln, and the like, into it.
 * adnshost is a general-purpose DNS lookup utility which can be used
   easily in from the command line and from shell scripts to do
   simple lookups. In a more advanced mode it can be used as a
   general-purpose DNS helper program for scripting languages which
   can invoke and communicate with subprocesses. See the [1]adnshost
   usage message for a summary of its capabilities.

%package -n %{libname}
Group:         System/Libraries
Summary:       Libraries needed to run applications using adns

%description -n %{libname}
adns is a resolver library for C (and C++) programs, and a collection of useful DNS resolver utilities.
In contrast with the existing interfaces, gethostbyname et al and libresolv, it has the following features:
 * It is reasonably easy to use for simple programs which just want
   to translate names to addresses, look up MX records, etc.
 * It can be used in an asynchronous, non-blocking, manner. Many
   queries can be handled simultaneously.
 * Responses are decoded automatically into a natural representation
   for a C program - there is no need to deal with DNS packet
   formats.
 * Sanity checking (eg, name syntax checking, reverse/forward
   correspondence, CNAME pointing to CNAME) is performed
   automatically.
 * Time-to-live, CNAME and other similar information is returned in
   an easy-to-use form, without getting in the way.
 * There is no global state in the library; resolver state is an
   opaque data structure which the client creates explicitly. A
   program can have several instances of the resolver.
 * Errors are reported to the application in a way that distinguishes
   the various causes of failure properly.
 * Understands conventional resolv.conf, but this can overridden by
   environment variables.
 * Flexibility. For example, the application can tell adns to: ignore
   environment variables (for setuid programs), disable sanity checks
   eg to return arbitrary data, override or ignore resolv.conf in
   favour of supplied configuration, etc.
 * Believed to be correct ! For example, will correctly back off to
   TCP in case of long replies or queries, or to other nameservers if
   several are available. It has sensible handling of bad responses
   etc.

This package contains all of adns libraries.

%package -n %{libname}-devel
Group:         Development/Libraries
Summary:       Advanced, easy to use, asynchronous-capable DNS client library
Requires:      %{libname} = %{version}-%{release}

%description -n %{libname}-devel
adns is a resolver library for C (and C++) programs, and a collection of useful DNS resolver utilities. 
In contrast with the existing interfaces, gethostbyname et al and libresolv, it has the following features:
 * It is reasonably easy to use for simple programs which just want
   to translate names to addresses, look up MX records, etc.
 * It can be used in an asynchronous, non-blocking, manner. Many
   queries can be handled simultaneously.
 * Responses are decoded automatically into a natural representation
   for a C program - there is no need to deal with DNS packet
   formats.
 * Sanity checking (eg, name syntax checking, reverse/forward
   correspondence, CNAME pointing to CNAME) is performed
   automatically.
 * Time-to-live, CNAME and other similar information is returned in
   an easy-to-use form, without getting in the way.
 * There is no global state in the library; resolver state is an
   opaque data structure which the client creates explicitly. A
   program can have several instances of the resolver.
 * Errors are reported to the application in a way that distinguishes
   the various causes of failure properly.
 * Understands conventional resolv.conf, but this can overridden by
   environment variables.
 * Flexibility. For example, the application can tell adns to: ignore
   environment variables (for setuid programs), disable sanity checks
   eg to return arbitrary data, override or ignore resolv.conf in
   favour of supplied configuration, etc.
 * Believed to be correct ! For example, will correctly back off to
   TCP in case of long replies or queries, or to other nameservers if
   several are available. It has sensible handling of bad responses
   etc.

This package contains static libraries and header files need for 
development.

%prep
%setup -q

%build
%configure
%make

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
%makeoldinstall

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/*
%doc README TODO changelog

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/*.so.*

%files -n %{libname}-devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/*.a

%changelog
* Mon May 06 2024 Automatic Build System <autodist@openmamba.org> 1.6.1-1mamba
- automatic version update by autodist

* Sun Jun 14 2020 Automatic Build System <autodist@mambasoft.it> 1.6.0-1mamba
- automatic version update by autodist

* Sat Aug 13 2016 Automatic Build System <autodist@mambasoft.it> 1.5.1-1mamba
- automatic update by autodist

* Tue Nov 04 2014 Automatic Build System <autodist@mambasoft.it> 1.5.0-1mamba
- automatic version update by autodist

* Sun Aug 18 2013 Automatic Build System <autodist@mambasoft.it> 1.4-3mamba
- automatic rebuild by autodist

* Wed May 14 2008 Aleph0 <aleph0@openmamba.org> 1.4-2mamba
- specfile updated

* Thu Oct 19 2006 Davide Madrisan <davide.madrisan@qilinux.it> 1.4-1qilnx
- update to version 1.4 by autospec

* Mon Jun 12 2006 Davide Madrisan <davide.madrisan@qilinux.it> 1.3-1qilnx
- update to version 1.3 by autospec

* Wed Feb 25 2004 Davide Madrisan <davide.madrisan@qilinux.it> 1.0-1qilnx
- first build
